#!/bin/bash
#

# build splines for art
# buildSplines.sh <opt|debug|prof>

extraqual=${1}
basequal=a7

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extra_opt="-o"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extra_opt="-d"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    extra_opt="-p"
else
   echo "ERROR: please define the extra qualifier"
   echo "USAGE: buildSplines.sh <opt|debug|prof>"
   exit 1
fi

echo "building for ${fullqual}"

source ${PRODUCTS}/setup
flvr=`ups flavor`
OS=`uname`

sourcedir=${PRODUCTS}/splines/v1_00_01/build/source
builddir=${PRODUCTS}/splines/v1_00_01/build/build-${flvr}


if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# start with clean build subdirectories
if [ -d ${builddir} ]
then
   rm -rf ${builddir}/splines-${qualdir}
else
   mkdir -p ${builddir}
fi

# setup gcc v4_6_1
setup gcc v4_6_1
gccver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.6.1" ]
then
  echo " OK - gcc version is ${gccver}"
else
  echo "ERROR: wrong gcc version ${gccver}"
  exit 1
fi

# setup cmake
setup cmake



echo " ---------------------------------------------- "
echo "build splines"
mkdir -p ${builddir}/splines-${qualdir}
if [ ! -d ${builddir}/splines-${qualdir} ]
then
   echo "ERROR: failed to create ${builddir}/splines-${qualdir}"
   exit 1
fi
cd ${builddir}/splines-${qualdir}
source ${sourcedir}/splines/ups/setup_for_development ${extra_opt}
set -x
cmake -DCMAKE_INSTALL_PREFIX=${PRODUCTS} -DCMAKE_BUILD_TYPE=$CETPKG_TYPE -Dqualifier:STRING=$CETPKG_QUAL $CETPKG_SOURCE
make
make test
make install 
set +x

echo " ---------------------------------------------- "


exit 0
