// delta-1-test.cc

#include "splines/Grid.h"
#include "splines/Spline.h"

#include <iostream>
#include <string>
#include <cmath>

using namespace splines;

//#define VERBOSE_checkDelta
//#define TRACE_checkDelta
//#define BRIEF_checkDelta


static bool testOneDeltaValue ( Spline<1> const & s, 
                                double x, double expectation ) 
{
  double value = s(x);
  if ( std::abs (value - expectation) > .000001 ) 
  {
    std::cout << "Unexpected value for delta function spline: \n"
              << "s(" << x << ") = " << value 
              << " (expected " << expectation << ")\n";
    return false;
  }  
  return true;
}

bool delta_ctor () 
{ DeltaFunction<1>dfn ( 5.0, 12.0, 100.0 );
  Spline<1> s ( dfn );  // s is now a spline representing this delta function
  // With this delta function, we expect the range of the spline to be 
  // -0.24to + .24.  We expect s(.12) to be 3.125, s(.08) to be 25,
  // s(.04) to be  71.875, and s(0) to be 100.  Oudside of |x| < .16
  // we expect the spline to be zero.
  //
  bool ok = true;
  double s0 = 5.0;
#ifdef TRACE_checkDelta
  std::cout << "Delta Function at 5 of strength 12 and max h = 100: \n"
            << s0-.21 << "   " << s(s0-.21) << "\n"  
            << s0-.17 << "   " << s(s0-.17) << "\n"  
            << s0-.12 << "   " << s(s0-.12) << "\n"  
            << s0-.08 << "   " << s(s0-.08) << "\n"  
            << s0-.04 << "   " << s(s0-.04) << "\n"  
            << s0 << "   " << s(s0) << "\n"  
            << s0+.04 << "   " << s(s0+.04) << "\n"  
            << s0+.08 << "   " << s(s0+.08) << "\n"  
            << s0+.12 << "   " << s(s0+.12) << "\n"  
            << s0+.17 << "   " << s(s0+.17) << "\n"  
            << s0+.21 << "   " << s(s0+.21) << "\n" 
            ; 
#endif
  ok &= testOneDeltaValue(s, s0-.21, 0);
  ok &= testOneDeltaValue(s, s0-.17, 0);
  ok &= testOneDeltaValue(s, s0-.12, 3.125);
  ok &= testOneDeltaValue(s, s0-.08, 25);
  ok &= testOneDeltaValue(s, s0-.04, 71.875);
  ok &= testOneDeltaValue(s, s0, 100);
  ok &= testOneDeltaValue(s, s0+.04, 71.875);
  ok &= testOneDeltaValue(s, s0+.08, 25);
  ok &= testOneDeltaValue(s, s0+.12, 3.125);
  ok &= testOneDeltaValue(s, s0+.17, 0);
  ok &= testOneDeltaValue(s, s0+.21, 0);
  return ok;
}

int main() {
  bool ok = true;
  ok &= delta_ctor();
  return ok ? 0:-1;
}
