// extremum-1-test.cc

#include "splines/Grid.h"
#include "splines/Spline.h"

#include <iostream>
#include <string>
#include <cmath>

using namespace splines;

//#define VERBOSE_checkDelta
//#define TRACE_checkDelta
//#define BRIEF_checkDelta


static bool testOneValue ( double x, double expectation, std::string message ) 
{
  if ( std::abs (x - expectation) > .000001 ) 
  {
    std::cout << "Unexpected value for " << message 
              << "  x = " << x 
              << " (expected " << expectation << ")\n";
    return false;
  }  
  return true;
}

double sinx (double x) { return std::sin(x); }
double cosx (double x) { return std::cos(x); }

double someCubic (double x) {
  return x*x*x - 8*(x-1)*(x-1);
  // This has a local minimum at 4/3 and a local maximum at 4
}

bool maximum () 
{   
  bool ok = true;
  Grid<1> g1(-4, 5, 77);
  Spline<1> scub  (someCubic, g1);
  double x = scub.maximum();
  ok &= testOneValue (x, 4.0/3.0, "maximum cubic");
  Grid<1> g2 ( -1, 3, 100 );
  Spline<1> sinspline (sinx, g2);
  x = sinspline.maximum();
  ok &= testOneValue (x, 3.1415926535/2, "maximum sin");
  Grid<1> g3(-10.0, 10.2, 101);
  Spline<1> scubFurther  (someCubic, g3);
  x = scubFurther.maximum();
  ok &= testOneValue (x, 10, "maximum cubic at endpoint");
  return ok;
}

bool minimum () 
{   
  bool ok = true;
  Grid<1> g1(0.5, 5, 85);
  Spline<1> scub  (someCubic, g1);
  double x = scub.minimum();
  ok &= testOneValue (x, 4, "minimum cubic");
  Grid<1> g2 ( 0, 4, 100 );
  Spline<1> cosspline (cosx, g2);
  x = cosspline.minimum();
  ok &= testOneValue (x, 3.1415926535, "miniumum cos");
  Grid<1> g3(-2, 5, 100);
  Spline<1> scubneg  (someCubic, g3);
  x = scubneg.minimum();
  ok &= testOneValue (x, -2, "minimum cubic at startpoint");
  return ok;
}

int main() {
  bool ok = true;
  ok &= maximum();
  ok &= minimum();
  return ok ? 0:-1;
}
